#!/bin/sh
#   Copyright (c) 2010 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of digitalSTROM Server.
#
#   netinfo.sh is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   netinfo.sh is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this file. If not, see <http://www.gnu.org/licenses/>.

# source common functions
. ./errlib.sh
. ./jsonlib.sh

export PATH=/usr/local/bin:/usr/bin:/bin:/usr/local/sbin:/usr/sbin:/sbin
export SHELL=/bin/sh

LOGDIR="/var/log/dss11-websetup"
FIRMWARE_DIRECTORY="/usr/share/dsm-firmware"
FW_TOOL=/usr/bin/dsm-firmware-upgrade
mkdir -p $LOGDIR > /dev/null 2>&1


json_fwchecked() {
    echo -n "{ \"success\": true, \"code\": $ERR_OK, \"message\": \"OK\", "
    echo -n "\"data\": { "
    echo -n "\"update\": $1 }"
    echo    " }"
}

echo "Content-Type: application/json"
echo ""

if [[ ! -x $FW_TOOL ]]; then
    json_error $ERR_SETUP "dSM firmware upgrade tool missing!"
    exit 1
fi

if [[ -e /var/lock/systemupdate ]]; then
    json_error $ERR_DOWAIT "Update application busy, please try again later"
    exit 1
fi

if [[ "$1" == "check" ]]; then
    if [[ ! -d "$FIRMWARE_DIRECTORY" ]]; then
        json_error $ERR_DSMFW "dSM firmware images not found on the system"
        exit 1
    fi

    if\
     [[ $(ls -1 "$FIRMWARE_DIRECTORY"/dsm-dsp*.img 2>/dev/null|wc -l) -ne 1 ]]\
     ||\
     [[ $(ls -1 "$FIRMWARE_DIRECTORY"/dsm-arm*.img 2>/dev/null|wc -l) -ne 1 ]];\
                                                                            then
        json_error $ERR_DSMFW "dSM firmware images not found or invalid"
        exit 1
    fi

    RETCODE=0
    for f in "$FIRMWARE_DIRECTORY"/dsm-dsp*.img \
             "$FIRMWARE_DIRECTORY"/dsm-arm*.img; do
        $FW_TOOL -u -p -B -f $f > /dev/null 2>&1
        RETCODE="$?"
        if [[ $RETCODE -ne 0 ]]; then
            break
        fi
    done
    json_fwchecked $RETCODE
# dsm-firmware-upgrade -u -p -B -f /usr/share/dsm-firmware/image..
elif [[ "$1" == "upgrade" ]]; then
    echo "[`date`] Starting dSM update script (\"$1\")" --- >> "$LOGDIR/update.log"
    nohup /www/scripts/dsmfwupgrade.sh >> "$LOGDIR/update.log" &
    if [[ "$?" -eq "$ERR_OK" ]]; then
        json_ok "OK"
        exit 0
    else
        json_error $ERR_UPDATE "Failed to start dSM firmware upgrade process!"
        exit 1
    fi

else 
    json_error $ERR_PARAM "Invalid option given!"
fi

